# NetManage
## About
NetManage is simple console program written as a background for GUI application. It uses custom file format to sotre connections data and reusable commands.

## Author
Jakub Olejnik\
[GitHub](https://github.com/JakubOlejnik2007)